@@ -69,10 +69,10 @@ sub stdio_state_errors {
 
       my $wstat = $?;
 
-      stirb "UTTER PANIC - \$wstat ($wstat) is too wide after executing '$tester'"
-        if $wstat > 0xFFFF_FFFF;
-
-      if ( ( $wstat & 0x1FFF ) != 0b0_1000_0000_0000 ) {
+      if ( $wstat > 0xFFFF ) {
+        push @$ret, "UTTER PANIC - \$wstat ($wstat) is too wide after executing '$tester'"
+      }
+      elsif ( ( $wstat & 0x1FFF ) != 0b0_1000_0000_0000 ) {
         push @$ret, sprintf (
           "Unexpected lower 13 bits while testing for '$tester': %03b.%b--%b.%03b--%04b--%04b ($wstat)",
 
